@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
-require 'ffi-glib/container_class_methods'
-require 'ffi-glib/array_methods'
+require "ffi-glib/container_class_methods"
+require "gir_ffi/array_element_convertor"
 
 GLib.load_class :Array
 
@@ -10,7 +10,6 @@ module GLib
   # be necessary to create objects of this class from Ruby directly.
   class Array
     include Enumerable
-    include ArrayMethods
     extend ContainerClassMethods
 
     attr_reader :element_type
@@ -70,6 +69,17 @@ module GLib
       self
     end
 
+    # Re-implementation of the g_array_index macro
+    def index(idx)
+      unless (0...length).cover? idx
+        raise IndexError, "Index #{idx} outside of bounds 0..#{length - 1}"
+      end
+
+      item_ptr = data_ptr + idx * element_size
+      convertor = GirFFI::ArrayElementConvertor.new element_type, item_ptr
+      convertor.to_ruby_value
+    end
+
     private
 
     def data_ptr
@@ -83,7 +93,7 @@ module GLib
     def check_element_size_match
       return if calculated_element_size == get_element_size
 
-      warn 'WARNING: Element sizes do not match'
+      warn "WARNING: Element sizes do not match"
     end
 
     def guess_element_type
