@@ -15,8 +15,13 @@ module GLib
       self.class.wrap Lib.g_byte_array_append(to_ptr, bytes, len)
     end
 
-    def initialize
-      store_pointer(Lib.g_byte_array_new)
+    def self.from(data)
+      case data
+      when self
+        data
+      else
+        new.append(data)
+      end
     end
   end
 end
