@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'ffi-glib/container_class_methods'
+require "ffi-glib/container_class_methods"
 
 GLib.load_class :HashTable
 
@@ -63,7 +63,7 @@ module GLib
       when :utf8
         FFI::Function.new(:uint,
                           [:pointer],
-                          find_support_function('g_str_hash'))
+                          find_support_function("g_str_hash"))
       end
     end
 
@@ -72,7 +72,7 @@ module GLib
       when :utf8
         FFI::Function.new(:int,
                           [:pointer, :pointer],
-                          find_support_function('g_str_equal'))
+                          find_support_function("g_str_equal"))
       end
     end
 
