@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'gir_ffi/property_not_found_error'
+require "gir_ffi/property_not_found_error"
 
 GObject.load_class :Object
 
@@ -44,7 +44,7 @@ module GObject
         obj
       end
     else
-      setup_method! 'new'
+      setup_method! "new"
 
       # Before GLib 2.54.0, use g_object_newv, which takes an array of GParameter.
       def initialize_with_automatic_gtype(properties = {})
@@ -90,22 +90,6 @@ module GObject
       end
     end
 
-    # TODO: Generate accessor methods from GIR at class definition time
-    def method_missing(method, *args)
-      getter_name = "get_#{method}"
-      return send(getter_name, *args) if respond_to?(getter_name)
-
-      if method.to_s =~ /(.*)=$/
-        setter_name = "set_#{Regexp.last_match[1]}"
-        return send(setter_name, *args) if respond_to?(setter_name)
-      end
-      super
-    end
-
-    def respond_to_missing?(*)
-      false
-    end
-
     def signal_connect(event, data = nil, &block)
       GObject.signal_connect(self, event, data, &block)
     end
@@ -114,30 +98,37 @@ module GObject
       GObject.signal_connect_after(self, event, data, &block)
     end
 
-    setup_instance_method! 'get_property'
-    setup_instance_method! 'set_property'
+    setup_instance_method! "get_property"
+    setup_instance_method! "set_property"
 
+    # @deprecated
     def get_property_extended(property_name)
-      value = get_property(property_name)
-      type_info = get_property_type property_name
-      property_value_post_conversion value, type_info
+      get_property(property_name)
     end
 
     def get_property_with_override(property_name)
       gvalue = gvalue_for_property property_name
       get_property_without_override property_name, gvalue
-      gvalue.get_value
+      value = gvalue.get_value
+
+      type_info = get_property_type property_name
+      value = property_value_post_conversion(value, type_info) if type_info
+
+      value
     end
 
+    # @deprecated
     def set_property_extended(property_name, value)
-      type_info = get_property_type property_name
-      adjusted_value = property_value_pre_conversion(value, type_info)
-      set_property property_name, adjusted_value
+      set_property property_name, value
     end
 
     def set_property_with_override(property_name, value)
+      type_info = get_property_type property_name
+      value = property_value_pre_conversion(value, type_info) if type_info
+
       gvalue = gvalue_for_property(property_name)
       gvalue.set_value value
+
       set_property_without_override property_name, gvalue
     end
 
@@ -147,7 +138,7 @@ module GObject
     alias set_property_without_override set_property
     alias set_property set_property_with_override
 
-    setup_instance_method! 'is_floating'
+    setup_instance_method! "is_floating"
     alias floating? is_floating
 
     private
@@ -165,8 +156,7 @@ module GObject
     end
 
     def get_property_type(property_name)
-      prop = self.class.find_property(property_name)
-      prop.property_type
+      self.class.find_property(property_name)&.property_type
     end
 
     def gvalue_for_property(property_name)
@@ -175,8 +165,7 @@ module GObject
     end
 
     def property_gtype(property_name)
-      pspec = property_param_spec(property_name)
-      pspec.value_type
+      property_param_spec(property_name).value_type
     end
 
     def property_param_spec(property_name)
@@ -207,6 +196,8 @@ module GObject
         GLib::List.from type_info.element_type, val
       when :strv
         GLib::Strv.from val
+      when :byte_array
+        GLib::ByteArray.from val
       when :callback
         GirFFI::Builder.build_class(type_info.interface).from val
       else
