@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'ffi-gobject/closure'
+require "ffi-gobject/closure"
 
 module GObject
   # Encapsulates Ruby blocks as GObject Closures.
@@ -36,7 +36,7 @@ module GObject
 
       result = rclosure.invoke_block(*args)
 
-      return_value.set_value(result) if return_value
+      return_value&.set_value(result)
     end
 
     # @api private
