@@ -1,26 +1,26 @@
 # frozen_string_literal: true
 
-require 'ffi-gobject_introspection/gobject_type_init'
+require "ffi-gobject_introspection/gobject_type_init"
 GObjectIntrospection::GObjectTypeInit.type_init
 
-require 'ffi-gobject_introspection/i_base_info'
-require 'ffi-gobject_introspection/i_callable_info'
-require 'ffi-gobject_introspection/i_callback_info'
-require 'ffi-gobject_introspection/i_function_info'
-require 'ffi-gobject_introspection/i_constant_info'
-require 'ffi-gobject_introspection/i_field_info'
-require 'ffi-gobject_introspection/i_registered_type_info'
-require 'ffi-gobject_introspection/i_interface_info'
-require 'ffi-gobject_introspection/i_property_info'
-require 'ffi-gobject_introspection/i_vfunc_info'
-require 'ffi-gobject_introspection/i_signal_info'
-require 'ffi-gobject_introspection/i_object_info'
-require 'ffi-gobject_introspection/i_struct_info'
-require 'ffi-gobject_introspection/i_value_info'
-require 'ffi-gobject_introspection/i_union_info'
-require 'ffi-gobject_introspection/i_enum_info'
-require 'ffi-gobject_introspection/i_flags_info'
-require 'ffi-gobject_introspection/i_unresolved_info'
+require "ffi-gobject_introspection/i_base_info"
+require "ffi-gobject_introspection/i_callable_info"
+require "ffi-gobject_introspection/i_callback_info"
+require "ffi-gobject_introspection/i_function_info"
+require "ffi-gobject_introspection/i_constant_info"
+require "ffi-gobject_introspection/i_field_info"
+require "ffi-gobject_introspection/i_registered_type_info"
+require "ffi-gobject_introspection/i_interface_info"
+require "ffi-gobject_introspection/i_property_info"
+require "ffi-gobject_introspection/i_vfunc_info"
+require "ffi-gobject_introspection/i_signal_info"
+require "ffi-gobject_introspection/i_object_info"
+require "ffi-gobject_introspection/i_struct_info"
+require "ffi-gobject_introspection/i_value_info"
+require "ffi-gobject_introspection/i_union_info"
+require "ffi-gobject_introspection/i_enum_info"
+require "ffi-gobject_introspection/i_flags_info"
+require "ffi-gobject_introspection/i_unresolved_info"
 
 module GObjectIntrospection
   # Map info type to class. Default is IBaseInfo.
@@ -49,4 +49,4 @@ module GObjectIntrospection
   }.freeze
 end
 
-require 'ffi-gobject_introspection/i_repository'
+require "ffi-gobject_introspection/i_repository"
