@@ -20,7 +20,7 @@ module GObjectIntrospection
     def value
       case type_tag
       when :utf8
-        raw_value.force_encoding('utf-8')
+        raw_value.force_encoding("utf-8")
       when :gboolean
         raw_value.nonzero? ? true : false
       else
@@ -29,7 +29,7 @@ module GObjectIntrospection
     end
 
     def constant_type
-      ITypeInfo.wrap Lib.g_constant_info_get_type self
+      @constant_type ||= ITypeInfo.wrap Lib.g_constant_info_get_type self
     end
 
     private
