@@ -5,11 +5,11 @@ module GObjectIntrospection
   # Represents a property of an IObjectInfo or an IInterfaceInfo.
   class IPropertyInfo < IBaseInfo
     def property_type
-      ITypeInfo.wrap Lib.g_property_info_get_type(self)
+      @property_type ||= ITypeInfo.wrap Lib.g_property_info_get_type(self)
     end
 
     def flags
-      Lib.g_property_info_get_flags self
+      @flags ||= Lib.g_property_info_get_flags self
     end
 
     def readable?
