@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'gir_ffi/class_base'
+require "gir_ffi/class_base"
 
 module GirFFI
   # Base class for generated classes representing boxed types.
