@@ -1,10 +1,10 @@
 # frozen_string_literal: true
 
-require 'gir_ffi/builders/type_builder'
-require 'gir_ffi/builders/module_builder'
-require 'gir_ffi/builder_helper'
-require 'gir_ffi/unintrospectable_type_info'
-require 'gir_ffi/unintrospectable_boxed_info'
+require "gir_ffi/builders/type_builder"
+require "gir_ffi/builders/module_builder"
+require "gir_ffi/builder_helper"
+require "gir_ffi/unintrospectable_type_info"
+require "gir_ffi/unintrospectable_boxed_info"
 
 module GirFFI
   # Builds modules and classes based on information found in the
@@ -19,11 +19,17 @@ module GirFFI
 
     def self.build_by_gtype(gtype)
       info = GObjectIntrospection::IRepository.default.find_by_gtype gtype
-      info ||= case GObject.type_fundamental gtype
-               when GObject::TYPE_BOXED
-                 UnintrospectableBoxedInfo.new gtype
-               when GObject::TYPE_OBJECT
-                 UnintrospectableTypeInfo.new gtype
+      info ||= begin
+                 fund = GObject.type_fundamental gtype
+                 if fund == GObject::TYPE_BOXED
+                   UnintrospectableBoxedInfo.new gtype
+                 elsif fund == GObject::TYPE_OBJECT
+                   UnintrospectableTypeInfo.new gtype
+                 elsif fund >= GObject::TYPE_RESERVED_USER_FIRST
+                   UnintrospectableTypeInfo.new gtype
+                 else
+                   raise "Unable to handle type #{GObject.type_name gtype}"
+                 end
                end
 
       build_class info
@@ -36,6 +42,8 @@ module GirFFI
         unless modul.const_defined? :GIR_FFI_BUILDER
           raise "The module #{module_name} was already defined elsewhere"
         end
+
+        return modul
       end
       Builders::ModuleBuilder.new(module_name,
                                   namespace: namespace,
