@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
-require 'gir_ffi/builders/return_value_builder'
-require 'gir_ffi/builders/base_method_builder'
+require "gir_ffi/builders/return_value_builder"
+require "gir_ffi/builders/base_method_builder"
 
 module GirFFI
   module Builders
@@ -37,12 +37,18 @@ module GirFFI
       private
 
       def receiver_call_argument
-        if @info.instance_ownership_transfer == :everything
-          'self.ref'
+        container_type_info = ReceiverTypeInfo.new(container_info)
+        if @info.instance_ownership_transfer == :everything &&
+            container_type_info.flattened_tag == :object
+          "self.ref"
         else
-          'self'
+          "self"
         end
       end
+
+      def container_info
+        @container_info ||= @info.container
+      end
     end
   end
 end
