@@ -1,11 +1,11 @@
 # frozen_string_literal: true
 
-require 'gir_ffi/builders/method_template'
-require 'gir_ffi/builders/argument_builder_collection'
-require 'gir_ffi/builders/property_argument_builder'
-require 'gir_ffi/builders/property_return_value_builder'
-require 'gir_ffi/variable_name_generator'
-require 'gir_ffi/field_argument_info'
+require "gir_ffi/builders/method_template"
+require "gir_ffi/builders/argument_builder_collection"
+require "gir_ffi/builders/property_argument_builder"
+require "gir_ffi/builders/property_return_value_builder"
+require "gir_ffi/variable_name_generator"
+require "gir_ffi/field_argument_info"
 
 module GirFFI
   module Builders
@@ -101,11 +101,11 @@ module GirFFI
       end
 
       def converting_setter_def
-        <<-CODE.reset_indentation
-        def #{setter_name} value
-          #{setter_builder.pre_conversion.join("\n")}
-          set_property("#{property_name}", #{setter_builder.call_argument_name})
-        end
+        <<~CODE
+          def #{setter_name} value
+            #{setter_builder.pre_conversion.join("\n")}
+            set_property("#{property_name}", #{setter_builder.call_argument_name})
+          end
         CODE
       end
 
@@ -132,7 +132,7 @@ module GirFFI
       end
 
       def argument_info
-        @argument_info ||= FieldArgumentInfo.new('value', type_info)
+        @argument_info ||= FieldArgumentInfo.new("value", type_info)
       end
 
       def container_class
@@ -143,6 +143,7 @@ module GirFFI
         @container_module ||= Object.const_get(container_info.safe_namespace)
       end
 
+      # TODO: Inject container_info on initialization
       def container_info
         @container_info ||= @info.container
       end
