@@ -1,10 +1,10 @@
 # frozen_string_literal: true
 
-require 'gir_ffi/builders/base_type_builder'
-require 'gir_ffi/method_stubber'
-require 'gir_ffi/builders/function_builder'
-require 'gir_ffi/builders/constructor_builder'
-require 'gir_ffi/builders/initializer_builder'
+require "gir_ffi/builders/base_type_builder"
+require "gir_ffi/method_stubber"
+require "gir_ffi/builders/function_builder"
+require "gir_ffi/builders/constructor_builder"
+require "gir_ffi/builders/initializer_builder"
 
 module GirFFI
   module Builders
@@ -77,6 +77,7 @@ module GirFFI
       def stub_methods
         info.get_methods.each do |minfo|
           klass.class_eval MethodStubber.new(minfo).method_stub, __FILE__, __LINE__
+          alias_accessors(minfo) if minfo.method?
         end
       end
 
@@ -92,6 +93,14 @@ module GirFFI
       def fields
         info.fields
       end
+
+      def alias_accessors(minfo)
+        if minfo.name =~ /^get_(.*)/
+          klass.send :alias_method, Regexp.last_match(1), minfo.name
+        elsif minfo.n_args == 1 && minfo.name =~ /^set_(.*)/
+          klass.send :alias_method, "#{Regexp.last_match(1)}=", minfo.name
+        end
+      end
     end
   end
 end
