@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
-require 'gir_ffi/builders/base_type_builder'
-require 'gir_ffi/builders/marshalling_method_builder'
+require "gir_ffi/builders/base_type_builder"
+require "gir_ffi/builders/marshalling_method_builder"
 
 module GirFFI
   module Builders
