@@ -1,8 +1,8 @@
 # frozen_string_literal: true
 
-require 'gir_ffi/builders/registered_type_builder'
-require 'gir_ffi/builders/struct_like'
-require 'gir_ffi/struct_base'
+require "gir_ffi/builders/registered_type_builder"
+require "gir_ffi/builders/struct_like"
+require "gir_ffi/struct_base"
 
 module GirFFI
   module Builders
@@ -16,7 +16,7 @@ module GirFFI
 
       def superclass
         # HACK: Inheritance chain is not expressed in GObject's code correctly.
-        return GObject::ObjectClass if info.full_type_name == 'GObject::InitiallyUnownedClass'
+        return GObject::ObjectClass if info.full_type_name == "GObject::InitiallyUnownedClass"
         return parent_field_type.tag_or_class if info.gtype_struct?
         return BoxedBase if GObject.type_fundamental(info.gtype) == GObject::TYPE_BOXED
 
