@@ -1,13 +1,34 @@
 # frozen_string_literal: true
 
-require 'gir_ffi/builder_helper'
+require "gir_ffi/builder_helper"
 
 module GirFFI
   module InfoExt
     # Extensions for GObjectIntrospection::ITypeInfo needed by GirFFI
     module ITypeInfo
+      FLATTENED_TAG_TO_GTYPE_MAP = {
+        gboolean: GObject::TYPE_BOOLEAN,
+        gint32:   GObject::TYPE_INT,
+        gint64:   GObject::TYPE_INT64,
+        guint64:  GObject::TYPE_UINT64,
+        void:     GObject::TYPE_NONE
+      }.freeze
+
+      FLATTENED_TAG_POINTER_TO_GTYPE_MAP = {
+        array: GObject::TYPE_ARRAY,
+        ghash: GObject::TYPE_HASH_TABLE,
+        strv:  GObject::TYPE_STRV,
+        utf8:  GObject::TYPE_STRING
+      }.freeze
+
       def gtype
-        TypeMap.type_info_to_gtype self
+        return interface.gtype if tag == :interface
+
+        if pointer?
+          FLATTENED_TAG_POINTER_TO_GTYPE_MAP.fetch(flattened_tag, GObject::TYPE_POINTER)
+        else
+          FLATTENED_TAG_TO_GTYPE_MAP.fetch(flattened_tag)
+        end
       end
 
       def make_g_value
@@ -24,14 +45,15 @@ module GirFFI
       end
 
       def flattened_tag
-        case tag
-        when :interface
-          interface_type
-        when :array
-          flattened_array_type
-        else
-          tag
-        end
+        @flattened_tag ||=
+          case tag
+          when :interface
+            interface_type
+          when :array
+            flattened_array_type
+          else
+            tag
+          end
       end
 
       def interface_type
@@ -59,22 +81,22 @@ module GirFFI
       end
 
       def interface_class
-        Builder.build_class interface if tag == :interface
+        @interface_class ||= Builder.build_class interface if tag == :interface
       end
 
       TAG_TO_WRAPPER_CLASS_MAP = {
-        array:           'GLib::Array',
-        byte_array:      'GLib::ByteArray',
-        c:               'GirFFI::SizedArray',
-        error:           'GLib::Error',
-        ghash:           'GLib::HashTable',
-        glist:           'GLib::List',
-        gslist:          'GLib::SList',
-        ptr_array:       'GLib::PtrArray',
-        strv:            'GLib::Strv',
-        utf8:            'GirFFI::InPointer', # TODO: Create a string-like class
-        void:            'GirFFI::InPointer', # TODO: Create a void-pointer class
-        zero_terminated: 'GirFFI::ZeroTerminated'
+        array:           "GLib::Array",
+        byte_array:      "GLib::ByteArray",
+        c:               "GirFFI::SizedArray",
+        error:           "GLib::Error",
+        ghash:           "GLib::HashTable",
+        glist:           "GLib::List",
+        gslist:          "GLib::SList",
+        ptr_array:       "GLib::PtrArray",
+        strv:            "GLib::Strv",
+        utf8:            "GirFFI::InPointer", # TODO: Create a string-like class
+        void:            "GirFFI::InPointer", # TODO: Create a void-pointer class
+        zero_terminated: "GirFFI::ZeroTerminated"
       }.freeze
 
       # TODO: Use class rather than class name
@@ -144,7 +166,7 @@ module GirFFI
       end
 
       def needs_c_to_ruby_conversion_for_closures?
-        [:array, :c, :ghash, :glist, :struct, :strv].include?(flattened_tag)
+        [:array, :c, :error, :ghash, :glist, :struct, :strv].include?(flattened_tag)
       end
 
       def needs_ruby_to_c_conversion_for_closures?
@@ -170,7 +192,7 @@ module GirFFI
         end
       end
 
-      GOBJECT_VALUE_NAME = 'GObject::Value'.freeze
+      GOBJECT_VALUE_NAME = "GObject::Value"
 
       def gvalue?
         argument_class_name == GOBJECT_VALUE_NAME
@@ -220,4 +242,4 @@ module GirFFI
   end
 end
 
-GObjectIntrospection::ITypeInfo.send :include, GirFFI::InfoExt::ITypeInfo
+GObjectIntrospection::ITypeInfo.include GirFFI::InfoExt::ITypeInfo
