@@ -1,8 +1,8 @@
 # frozen_string_literal: true
 
-require 'gir_ffi/registered_type_base'
-require 'gir_ffi/method_setup'
-require 'gir_ffi/instance_method_setup'
+require "gir_ffi/registered_type_base"
+require "gir_ffi/method_setup"
+require "gir_ffi/instance_method_setup"
 
 module GirFFI
   # Base module for modules representing GLib interfaces.
