@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'gir_ffi/class_base'
+require "gir_ffi/class_base"
 
 module GirFFI
   # Base class for all generated classes of type :object.
@@ -38,7 +38,7 @@ module GirFFI
     end
 
     def self.copy_from(val)
-      val.ref if val
+      val&.ref
     end
 
     #
@@ -49,8 +49,7 @@ module GirFFI
     # @return [GObjectIntrospection::IPropertyInfo] The property's info
     #
     def self.find_property(name)
-      gir_ffi_builder.find_property name or
-        raise GirFFI::PropertyNotFoundError.new(name, self)
+      gir_ffi_builder.find_property name
     end
 
     #
