@@ -1,22 +1,29 @@
 # frozen_string_literal: true
 
-require 'simplecov'
-SimpleCov.start do
-  track_files 'lib/**/*.rb'
-  add_filter '/test/'
-end
+old_verbose = $VERBOSE
+$VERBOSE = false
+begin
+  require "test-prof"
 
-if ENV['CI']
+  TestProf::RubyProf.configure do |config|
+    config.min_percent = 0.5
+  end
+rescue LoadError
+  warn "test-prof not available"
+end
+$VERBOSE = old_verbose
+
+if ENV["CI"]
   begin
-    require 'coveralls'
+    require "coveralls"
     Coveralls.wear!
   rescue LoadError
     nil
   end
 end
 
-require 'minitest/autorun'
-require 'rspec/mocks/minitest_integration'
+require "minitest/autorun"
+require "rspec/mocks/minitest_integration"
 
 Thread.abort_on_exception = true
 
@@ -60,4 +67,4 @@ module BaseTestExtensions
   end
 end
 
-Minitest::Test.send :include, BaseTestExtensions
+Minitest::Test.include BaseTestExtensions
