@@ -1,12 +1,12 @@
 # frozen_string_literal: true
 
-require 'gir_ffi_test_helper'
+require "gir_ffi_test_helper"
 
 class MainLoopTestException < RuntimeError; end
 
 describe GLib::MainLoop do
-  describe '#run' do
-    it 'allows other threads to run' do
+  describe "#run" do
+    it "allows other threads to run" do
       main_loop = GLib::MainLoop.new nil, false
 
       a = []
@@ -16,26 +16,26 @@ describe GLib::MainLoop do
 
       slow_thread = Thread.new do
         sleep 0.001
-        a << 'During run'
+        a << "During run"
       end
 
-      a << 'Before run'
+      a << "Before run"
       main_loop.run
-      a << 'After run'
+      a << "After run"
 
       slow_thread.join
 
-      a.must_equal ['Before run', 'During run', 'After run']
+      _(a).must_equal ["Before run", "During run", "After run"]
     end
 
-    it 'raises and quits on exceptions in callbacks' do
+    it "raises and quits on exceptions in callbacks" do
       main_loop = GLib::MainLoop.new nil, false
 
-      a = 'expected'
+      a = "expected"
 
       # This timeout shouldn't get called
       guard = GLib.timeout_add GLib::PRIORITY_DEFAULT, 150 do
-        a = 'unexpected'
+        a = "unexpected"
         main_loop.quit
       end
 
@@ -43,8 +43,8 @@ describe GLib::MainLoop do
         raise MainLoopTestException
       end
 
-      -> { main_loop.run }.must_raise MainLoopTestException
-      a.must_equal 'expected'
+      _(-> { main_loop.run }).must_raise MainLoopTestException
+      _(a).must_equal "expected"
 
       # Clean up uncalled timeout
       GLib.source_remove guard
