@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'introspection_test_helper'
+require "introspection_test_helper"
 
 describe GObjectIntrospection::IFunctionInfo do
 end
