@@ -1,16 +1,16 @@
 # frozen_string_literal: true
 
-require 'gir_ffi_test_helper'
+require "gir_ffi_test_helper"
 
 describe GirFFI::Builders::ConstructorBuilder do
-  describe '#method_definition' do
+  describe "#method_definition" do
     let(:builder) { GirFFI::Builders::ConstructorBuilder.new function_info }
     let(:code) { builder.method_definition }
 
-    describe 'for constructors with the default name' do
-      let(:function_info) { get_method_introspection_data 'Regress', 'TestObj', 'new' }
-      it 'builds a constructor' do
-        code.must_equal <<-CODE.reset_indentation
+    describe "for constructors with the default name" do
+      let(:function_info) { get_method_introspection_data "Regress", "TestObj", "new" }
+      it "builds a constructor" do
+        _(code).must_equal <<~CODE
           def self.new(*args, &block)
             obj = allocate
             obj.__send__ :initialize, *args, &block
@@ -20,10 +20,10 @@ describe GirFFI::Builders::ConstructorBuilder do
       end
     end
 
-    describe 'for constructors with a custom name' do
-      let(:function_info) { get_method_introspection_data 'Regress', 'TestObj', 'new_from_file' }
-      it 'builds a custom constructor' do
-        code.must_equal <<-CODE.reset_indentation
+    describe "for constructors with a custom name" do
+      let(:function_info) { get_method_introspection_data "Regress", "TestObj", "new_from_file" }
+      it "builds a custom constructor" do
+        _(code).must_equal <<~CODE
           def self.new_from_file(*args, &block)
             raise NoMethodError unless self == Regress::TestObj
             obj = allocate
