@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'gir_ffi_test_helper'
+require "gir_ffi_test_helper"
 
 GirFFI.setup :Regress
 
@@ -13,20 +13,20 @@ describe GirFFI::InfoExt::ISignalInfo do
   end
   let(:signal_info) { signal_class.new }
 
-  describe '#arguments_to_gvalues' do
+  describe "#arguments_to_gvalues" do
     let(:object) { Regress::TestSubObj.new }
     let(:boxed) { Regress::TestSimpleBoxedA.const_return }
-    let(:signal_info) { Regress::TestSubObj.find_signal 'test-with-static-scope-arg' }
+    let(:signal_info) { Regress::TestSubObj.find_signal "test-with-static-scope-arg" }
     let(:result) { signal_info.arguments_to_gvalues(object, [boxed]) }
 
-    it 'correctly wraps :object' do
-      result[0].get_value.must_equal object
+    it "correctly wraps :object" do
+      _(result[0].get_value).must_equal object
     end
 
-    it 'correctly wraps :struct' do
+    it "correctly wraps :struct" do
       result_boxed = result[1].get_value
-      result_boxed.some_int8.must_equal boxed.some_int8
-      result_boxed.some_int.must_equal boxed.some_int
+      _(result_boxed.some_int8).must_equal boxed.some_int8
+      _(result_boxed.some_int).must_equal boxed.some_int
     end
   end
 end
