@@ -1,18 +1,18 @@
 # frozen_string_literal: true
 
-require 'gir_ffi_test_helper'
-require 'gir_ffi/unintrospectable_type_info'
+require "gir_ffi_test_helper"
+require "gir_ffi/unintrospectable_type_info"
 
 describe GirFFI::UnintrospectableTypeInfo do
-  describe '#info_type' do
-    it 'returns :unintrospectable' do
+  describe "#info_type" do
+    it "returns :unintrospectable" do
       info = GirFFI::UnintrospectableTypeInfo.new :some_type
-      info.info_type.must_equal :unintrospectable
+      _(info.info_type).must_equal :unintrospectable
     end
   end
 
-  describe '#parent' do
-    describe 'when the GIR knows about the parent gtype' do
+  describe "#parent" do
+    describe "when the GIR knows about the parent gtype" do
       it "finds the parent's info by gtype" do
         gobject = Object.new
         gir = Object.new
@@ -22,12 +22,12 @@ describe GirFFI::UnintrospectableTypeInfo do
 
         info = GirFFI::UnintrospectableTypeInfo.new(:some_type, gir, gobject)
 
-        info.parent.must_equal :foo_info
+        _(info.parent).must_equal :foo_info
       end
     end
 
-    describe 'when the GIR does not know about the parent gtype' do
-      it 'creates a new UnintrospectableTypeInfo from the parent gtype' do
+    describe "when the GIR does not know about the parent gtype" do
+      it "creates a new UnintrospectableTypeInfo from the parent gtype" do
         gobject = Object.new
         gir = Object.new
 
@@ -36,13 +36,13 @@ describe GirFFI::UnintrospectableTypeInfo do
 
         info = GirFFI::UnintrospectableTypeInfo.new(:some_type, gir, gobject)
 
-        info.parent.g_type.must_equal :foo
+        _(info.parent.g_type).must_equal :foo
       end
     end
   end
 
-  describe '#interfaces' do
-    it 'finds interface infos by gtype' do
+  describe "#interfaces" do
+    it "finds interface infos by gtype" do
       gobject = Object.new
       gir = Object.new
 
@@ -52,10 +52,10 @@ describe GirFFI::UnintrospectableTypeInfo do
 
       info = GirFFI::UnintrospectableTypeInfo.new(:some_type, gir, gobject)
 
-      info.interfaces.must_equal [:foo_info, :bar_info]
+      _(info.interfaces).must_equal [:foo_info, :bar_info]
     end
 
-    it 'skips interfaces that have no introspection data' do
+    it "skips interfaces that have no introspection data" do
       gobject = Object.new
       gir = Object.new
 
@@ -65,25 +65,25 @@ describe GirFFI::UnintrospectableTypeInfo do
 
       info = GirFFI::UnintrospectableTypeInfo.new(:some_type, gir, gobject)
 
-      info.interfaces.must_equal [:foo_info]
+      _(info.interfaces).must_equal [:foo_info]
     end
   end
 
-  describe '#g_type' do
-    it 'returns the passed-in gtype' do
+  describe "#g_type" do
+    it "returns the passed-in gtype" do
       info = GirFFI::UnintrospectableTypeInfo.new(:some_type)
-      info.g_type.must_equal :some_type
+      _(info.g_type).must_equal :some_type
     end
   end
 
-  describe '#fields' do
-    it 'returns an empty array' do
+  describe "#fields" do
+    it "returns an empty array" do
       info = GirFFI::UnintrospectableTypeInfo.new(:some_type)
-      info.fields.must_equal []
+      _(info.fields).must_equal []
     end
   end
 
-  describe '#namespace' do
+  describe "#namespace" do
     it "returns the parent class' namespace" do
       gobject = Object.new
       gir = Object.new
@@ -91,31 +91,31 @@ describe GirFFI::UnintrospectableTypeInfo do
 
       expect(gobject).to receive(:type_parent).with(:some_type).and_return :foo
       expect(gir).to receive(:find_by_gtype).with(:foo).and_return parent_info
-      expect(parent_info).to receive(:namespace).and_return 'FooNamespace'
+      expect(parent_info).to receive(:namespace).and_return "FooNamespace"
 
       info = GirFFI::UnintrospectableTypeInfo.new(:some_type, gir, gobject)
 
-      info.namespace.must_equal 'FooNamespace'
+      _(info.namespace).must_equal "FooNamespace"
     end
   end
 
-  describe '#safe_name' do
-    it 'finds the class name by gtype' do
+  describe "#safe_name" do
+    it "finds the class name by gtype" do
       gobject = Object.new
 
-      expect(gobject).to receive(:type_name).with(:some_type).and_return 'GSomeType'
+      expect(gobject).to receive(:type_name).with(:some_type).and_return "GSomeType"
 
       info = GirFFI::UnintrospectableTypeInfo.new(:some_type, nil, gobject)
 
-      info.safe_name.must_equal 'GSomeType'
+      _(info.safe_name).must_equal "GSomeType"
     end
   end
 
-  describe '#find_signal' do
-    it 'indicates that no signals can be found' do
+  describe "#find_signal" do
+    it "indicates that no signals can be found" do
       info = GirFFI::UnintrospectableTypeInfo.new(:some_type)
-      result = info.find_signal 'any'
-      result.must_be_nil
+      result = info.find_signal "any"
+      _(result).must_be_nil
     end
   end
 end
