@@ -1,8 +1,8 @@
 # frozen_string_literal: true
 
-require 'introspection_test_helper'
+require "introspection_test_helper"
 
-require 'gir_ffi'
+require "gir_ffi"
 
 # Global sequence provider. Needed to make unique class names.
 class Sequence
@@ -81,4 +81,4 @@ module GirFFITestExtensions
   end
 end
 
-Minitest::Test.send :include, GirFFITestExtensions
+Minitest::Test.include GirFFITestExtensions
