@@ -1,17 +1,11 @@
 # frozen_string_literal: true
 
-require 'gir_ffi_test_helper'
+require "gir_ffi_test_helper"
 
-describe 'The generated WarnLib module' do
-  before do
-    begin
-      GirFFI.setup :WarnLib
-    rescue RuntimeError
-      skip 'WarnLib GIR not available'
-    end
-  end
+GirFFI.setup :WarnLib
 
-  describe 'WarnLib::Whatever' do
+describe "The generated WarnLib module" do
+  describe "WarnLib::Whatever" do
     let(:derived_klass) do
       Object.const_set("DerivedClass#{Sequence.next}", Class.new(GObject::Object))
     end
@@ -27,23 +21,23 @@ describe 'The generated WarnLib module' do
 
     let(:instance) { derived_klass.new }
 
-    it 'has a working method #do_boo' do
+    it "has a working method #do_boo" do
       instance.do_boo 42, nil
-      @result.must_equal 'boo42'
+      _(@result).must_equal "boo42"
     end
 
-    it 'has a working method #do_moo' do
+    it "has a working method #do_moo" do
       instance.do_moo 23, nil
-      @result.must_equal 'moo23'
+      _(@result).must_equal "moo23"
     end
   end
 
-  it 'has a working function #throw_unpaired' do
-    proc { WarnLib.throw_unpaired }.must_raise GirFFI::GLibError
+  it "has a working function #throw_unpaired" do
+    _(proc { WarnLib.throw_unpaired }).must_raise GirFFI::GLibError
   end
 
-  it 'has a working function #unpaired_error_quark' do
+  it "has a working function #unpaired_error_quark" do
     result = WarnLib.unpaired_error_quark
-    GLib.quark_to_string(result).must_equal 'warnlib-unpaired-error'
+    _(GLib.quark_to_string(result)).must_equal "warnlib-unpaired-error"
   end
 end
