@@ -1,16 +1,16 @@
 # frozen_string_literal: true
 
-require 'gir_ffi_test_helper'
+require "gir_ffi_test_helper"
 
 # Tests how methods are looked up and generated on first use.
-describe 'Looking up methods' do
+describe "Looking up methods" do
   before do
     save_module :Regress
     GirFFI.setup :Regress
   end
 
-  describe 'an instance method' do
-    it 'is found from a subclass' do
+  describe "an instance method" do
+    it "is found from a subclass" do
       assert_defines_instance_method Regress::TestObj, :forced_method
       refute_defines_instance_method Regress::TestSubObj, :forced_method
 
@@ -19,8 +19,8 @@ describe 'Looking up methods' do
     end
   end
 
-  describe 'a class method' do
-    it 'is found from a subclass' do
+  describe "a class method" do
+    it "is found from a subclass" do
       assert_defines_singleton_method Regress::TestObj, :static_method
       refute_defines_singleton_method Regress::TestSubObj, :static_method
 
